@@ -8,7 +8,16 @@ from argparse import Action, _ArgumentGroup
 from collections import ChainMap, OrderedDict
 from json import dumps
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Callable, Iterable, Mapping, MutableMapping, cast
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    Iterable,
+    Mapping,
+    MutableMapping,
+    cast,
+    no_type_check,
+)
 
 import tomlkit
 from packaging.specifiers import SpecifierSet
@@ -143,7 +152,10 @@ def build_dependency_graph(
             requirements = (
                 parse_requirement(r)
                 for r in filter_requirements_with_extras(
-                    dist.metadata["Name"], dist.requires or [], extras  # type: ignore
+                    cast(str, dist.metadata["Name"]),
+                    dist.requires or [],
+                    extras,
+                    include_default=True,
                 )
             )
             for req in requirements:
@@ -516,6 +528,7 @@ def find_importable_files(project: Project) -> Iterable[tuple[str, Path]]:
                 yield key, project_file
 
 
+@no_type_check
 def set_env_in_reg(env_name: str, value: str) -> None:
     """Manipulate the WinReg, and add value to the
     environment variable if exists or create new.
@@ -661,7 +674,7 @@ def get_dist_location(dist: Distribution) -> str:
     direct_url_data = json.loads(direct_url)
     url = cast(str, direct_url_data["url"])
     if url.startswith("file:"):
-        path = url_to_path(url)
+        path = url_to_path(url).replace("/${PROJECT_ROOT}", ".")
         editable = direct_url_data.get("dir_info", {}).get("editable", False)
         return f"{'-e ' if editable else ''}{path}"
     return ""
